@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-glib-0.12.5.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: glib
-version: 0.12.4
-id: glib-0.12.4-d1f299818663664519b8d947e0784cb7
+version: 0.12.5.4
+id: glib-0.12.5.4-d17f895d256b06ee8202922370af528b
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
@@ -28,21 +29,22 @@ exposed-modules: System.Glib System.Glib.GError
                  System.Glib.GValueTypes System.Glib.GParameter
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/glib-0.12.4
-library-dirs: /usr/local/lib/ghc/glib-0.12.4 /usr/local/lib
-hs-libraries: HSglib-0.12.4
+import-dirs: /usr/local/lib/ghc/glib-0.12.5.4
+library-dirs: /usr/local/lib/ghc/glib-0.12.5.4 /usr/local/lib
+hs-libraries: HSglib-0.12.5.4
 extra-libraries: gobject-2.0 glib-2.0 intl
 extra-ghci-libraries:
 include-dirs: /usr/local/include/glib-2.0
               /usr/local/lib/glib-2.0/include /usr/local/include
 includes:
-depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.4/html/glib.haddock
-haddock-html: /usr/local/share/doc/hs-glib-0.12.4/html
+haddock-interfaces: /usr/local/share/doc/hs-glib-0.12.5.4/html/glib.haddock
+haddock-html: /usr/local/share/doc/hs-glib-0.12.5.4/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
